==> grepWin-1.6.12.654-151205-0336.zip: src/resource.h <==
/ / { { N O _ D E P E N D E N C I E S } } 
 
 / /   M i c r o s o f t   V i s u a l   C + +   g e n e r a t e d   i n c l u d e   f i l e . 
 
 / /   U s e d   b y   D : \ D e v e l o p m e n t \ g r e p w i n \ s r c \ R e s o u r c e s \ g r e p W i n . r c 
 
 / / 
 
 # d e f i n e   I D S _ A P P _ T I T L E                                       1 0 3 
 
 # d e f i n e   I D S _ N A M E                                                 1 0 4 
 
 # d e f i n e   I D S _ S E A R C H S T R I N G                                 1 0 5 
 
 # d e f i n e   I D S _ R E P L A C E S T R I N G                               1 0 6 
 
 # d e f i n e   I D I _ G R E P W I N                                           1 0 7 
 
 # d e f i n e   I D S _ N O T E S T T E X T A V A I L A B L E                   1 0 7 
 
 # d e f i n e   I D S _ S E A R C H S T R I N G E M P T Y                       1 0 8 
 
 # d e f i n e   I D C _ G R E P W I N                                           1 0 9 
 
 # d e f i n e   I D S _ N O R E P L A C E T E X T                               1 1 0 
 
 # d e f i n e   I D S _ N O M A T C H                                           1 1 1 
 
 # d e f i n e   I D S _ P A T T E R N _ T T                                     1 1 2 
 
 # d e f i n e   I D S _ E X C L U D E D I R _ T T                               1 1 3 
 
 # d e f i n e   I D S _ S E A R C H P A T H _ T T                               1 1 4 
 
 # d e f i n e   I D S _ D O T M A T C H N E W L I N E _ T T                     1 1 5 
 
 # d e f i n e   I D S _ S E A R C H T E X T _ T T                               1 1 6 
 
 # d e f i n e   I D S _ O N L Y O N E _ T T                                     1 1 7 
 
 # d e f i n e   I D S _ E D I T M U L T I L I N E _ T T                         1 1 8 
 
 # d e f i n e   I D S _ A B O U T                                               1 1 9 
 
 # d e f i n e   I D S _ L E S S T H A N                                         1 2 0 
 
 # d e f i n e   I D S _ E Q U A L T O                                           1 2 1 
 
 # d e f i n e   I D S _ G R E A T E R T H A N                                   1 2 2 
 
 # d e f i n e   I D S _ S E A R C H                                             1 2 3 
 
 # d e f i n e   I D S _ R E P L A C E C O N F I R M                             1 2 4 
 
 # d e f i n e   I D S _ A N E M P T Y S T R I N G                               1 2 5 
 
 # d e f i n e   I D S _ S T O P                                                 1 2 6 
 
 # d e f i n e   I D S _ S E L E C T P A T H T O S E A R C H                     1 2 7 
 
 # d e f i n e   I D S _ I N F O L A B E L                                       1 2 8 
 
 # d e f i n e   I D D _ S E A R C H D L G                                       1 2 9 
 
 # d e f i n e   I D S _ R E A D E R R O R                                       1 2 9 
 
 # d e f i n e   I D D _ R E G E X T E S T                                       1 3 0 
 
 # d e f i n e   I D S _ B I N A R Y                                             1 3 0 
 
 # d e f i n e   I D D _ N A M E                                                 1 3 1 
 
 # d e f i n e   I D S _ R E G E X O K                                           1 3 1 
 
 # d e f i n e   I D D _ B O O K M A R K S                                       1 3 2 
 
 # d e f i n e   I D S _ R E G E X I N V A L I D                                 1 3 2 
 
 # d e f i n e   I D C _ B K P O P U P                                           1 3 3 
 
 # d e f i n e   I D S _ S I Z E                                                 1 3 3 
 
 # d e f i n e   I D R _ I N F O D L G                                           1 3 4 
 
 # d e f i n e   I D S _ L I N E                                                 1 3 4 
 
 # d e f i n e   I D D _ A B O U T                                               1 3 5 
 
 # d e f i n e   I D S _ M A T C H E S                                           1 3 5 
 
 # d e f i n e   I D R _ S E A R C H D L G                                       1 3 6 
 
 # d e f i n e   I D S _ T E X T                                                 1 3 6 
 
 # d e f i n e   I D D _ M U L T I L I N E E D I T                               1 3 7 
 
 # d e f i n e   I D S _ P A T H                                                 1 3 7 
 
 # d e f i n e   I D D _ S E T T I N G S                                         1 3 8 
 
 # d e f i n e   I D S _ E N C O D I N G                                         1 3 8 
 
 # d e f i n e   I D S _ D A T E M O D I F I E D                                 1 3 9 
 
 # d e f i n e   I D S _ S E L E C T E D I T O R                                 1 4 0 
 
 # d e f i n e   I D S _ O P E N W I T H E D I T O R                             1 4 1 
 
 # d e f i n e   I D S _ O P E N C O N T A I N I N G F O L D E R                 1 4 2 
 
 # d e f i n e   I D S _ C O P Y P A T H                                         1 4 3 
 
 # d e f i n e   I D S _ C O P Y P A T H S                                       1 4 4 
 
 # d e f i n e   I D S _ C O P Y F I L E N A M E                                 1 4 5 
 
 # d e f i n e   I D S _ C O P Y F I L E N A M E S                               1 4 6 
 
 # d e f i n e   I D S _ C O P Y R E S U L T                                     1 4 7 
 
 # d e f i n e   I D S _ C O P Y R E S U L T S                                   1 4 8 
 
 # d e f i n e   I D S _ X M O R E M A T C H E S                                 1 4 9 
 
 # d e f i n e   I D S _ C O N T E X T L I N E                                   1 5 0 
 
 # d e f i n e   I D S _ I N F O L A B E L F I L E                               1 5 1 
 
 # d e f i n e   I D S _ E R R _ R E L A T I V E P A T H                         1 5 2 
 
 # d e f i n e   I D S _ E R R _ I N V A L I D _ P A T H                         1 5 3 
 
 # d e f i n e   I D C _ S E A R C H T E X T                                     1 0 0 0 
 
 # d e f i n e   I D C _ R E G E X R A D I O                                     1 0 0 1 
 
 # d e f i n e   I D C _ T E X T R A D I O                                       1 0 0 2 
 
 # d e f i n e   I D C _ R E G E X O K L A B E L                                 1 0 0 4 
 
 # d e f i n e   I D C _ A L L S I Z E R A D I O                                 1 0 0 5 
 
 # d e f i n e   I D C _ S I Z E R A D I O                                       1 0 0 6 
 
 # d e f i n e   I D C _ S I Z E C O M B O                                       1 0 0 7 
 
 # d e f i n e   I D C _ S I Z E E D I T                                         1 0 0 8 
 
 # d e f i n e   I D C _ I N C L U D E S Y S T E M                               1 0 0 9 
 
 # d e f i n e   I D C _ I N C L U D E H I D D E N                               1 0 1 0 
 
 # d e f i n e   I D C _ I N C L U D E S U B F O L D E R S                       1 0 1 1 
 
 # d e f i n e   I D C _ S E A R C H P A T H                                     1 0 1 2 
 
 # d e f i n e   I D C _ S E A R C H P A T H B R O W S E                         1 0 1 3 
 
 # d e f i n e   I D C _ R E S U L T L I S T                                     1 0 1 4 
 
 # d e f i n e   I D C _ G R O U P S E A R C H I N                               1 0 1 5 
 
 # d e f i n e   I D C _ G R O U P S E A R C H F O R                             1 0 1 6 
 
 # d e f i n e   I D C _ G R O U P L I M I T S E A R C H                         1 0 1 7 
 
 # d e f i n e   I D C _ G R O U P S E A R C H R E S U L T S                     1 0 1 8 
 
 # d e f i n e   I D C _ K B T E X T                                             1 0 1 9 
 
 # d e f i n e   I D C _ S E A R C H I N F O L A B E L                           1 0 2 0 
 
 # d e f i n e   I D C _ A D D T O B O O K M A R K S                             1 0 2 1 
 
 # d e f i n e   I D C _ B O O K M A R K S                                       1 0 2 2 
 
 # d e f i n e   I D C _ R E P L A C E T E X T                                   1 0 2 3 
 
 # d e f i n e   I D C _ S E A R C H F O R L A B E L                             1 0 2 6 
 
 # d e f i n e   I D C _ R E P L A C E W I T H L A B E L                         1 0 2 7 
 
 # d e f i n e   I D C _ T E S T R E G E X                                       1 0 2 8 
 
 # d e f i n e   I D C _ C R E A T E B A C K U P                                 1 0 2 9 
 
 # d e f i n e   I D C _ T E X T C O N T E N T                                   1 0 3 0 
 
 # d e f i n e   I D C _ R E G E X M A T C H                                     1 0 3 1 
 
 # d e f i n e   I D C _ R E G E X R E P L A C E D                               1 0 3 2 
 
 # d e f i n e   I D C _ N A M E                                                 1 0 3 7 
 
 # d e f i n e   I D C _ P A T T E R N L A B E L                                 1 0 3 9 
 
 # d e f i n e   I D C _ P A T T E R N                                           1 0 4 0 
 
 # d e f i n e   I D C _ E X C L U D E _ D I R S _ P A T T E R N L A B E L       1 0 4 1 
 
 # d e f i n e   I D C _ C A S E _ S E N S I T I V E                             1 0 4 2 
 
 # d e f i n e   I D C _ V E R S I O N I N F O                                   1 0 4 3 
 
 # d e f i n e   I D C _ E X C L U D E D I R S P A T T E R N                     1 0 4 3 
 
 # d e f i n e   I D C _ D A T E                                                 1 0 4 4 
 
 # d e f i n e   I D C _ W E B L I N K                                           1 0 4 5 
 
 # d e f i n e   I D C _ F I L E P A T T E R N R E G E X                         1 0 4 6 
 
 # d e f i n e   I D C _ F I L E P A T T E R N T E X T                           1 0 4 8 
 
 # d e f i n e   I D C _ R E P L A C E                                           1 0 4 9 
 
 # d e f i n e   I D C _ I N C L U D E B I N A R Y                               1 0 5 0 
 
 # d e f i n e   I D C _ D O T M A T C H N E W L I N E                           1 0 5 1 
 
 # d e f i n e   I D C _ A B O U T L I N K                                       1 0 5 2 
 
 # d e f i n e   I D C _ U T F 8                                                 1 0 5 3 
 
 # d e f i n e   I D C _ I N F O L A B E L                                       1 0 5 6 
 
 # d e f i n e   I D C _ R E S U L T F I L E S                                   1 0 5 9 
 
 # d e f i n e   I D C _ R A D I O 2                                             1 0 6 0 
 
 # d e f i n e   I D C _ R E S U L T C O N T E N T                               1 0 6 0 
 
 # d e f i n e   I D C _ B U T T O N 1                                           1 0 6 1 
 
 # d e f i n e   I D C _ H E L P B U T T O N                                     1 0 6 1 
 
 # d e f i n e   I D C _ E D I T M U L T I L I N E 1                             1 0 6 1 
 
 # d e f i n e   I D C _ C H E C K 1                                             1 0 6 2 
 
 # d e f i n e   I D C _ O N L Y O N E                                           1 0 6 2 
 
 # d e f i n e   I D C _ E S C K E Y                                             1 0 6 2 
 
 # d e f i n e   I D C _ E D I T M U L T I L I N E 2                             1 0 6 3 
 
 # d e f i n e   I D C _ P A T H M R U                                           1 0 6 4 
 
 # d e f i n e   I D C _ H E L P L A B E L                                       1 0 6 5 
 
 # d e f i n e   I D C _ E X C L U D E D I R M R U                               1 0 6 6 
 
 # d e f i n e   I D C _ E D I T O R C M D                                       1 0 6 6 
 
 # d e f i n e   I D C _ P A T T E R N M R U                                     1 0 6 7 
 
 # d e f i n e   I D C _ E D I T O R G R O U P                                   1 0 6 7 
 
 # d e f i n e   I D C _ S T A T I C 1                                           1 0 6 8 
 
 # d e f i n e   I D C _ S T A T I C 2                                           1 0 6 9 
 
 # d e f i n e   I D C _ S E T T I N G S B U T T O N                             1 0 7 1 
 
 # d e f i n e   I D C _ P R O G R E S S                                         1 0 7 2 
 
 # d e f i n e   I D C _ L A N G U A G E                                         1 0 7 3 
 
 # d e f i n e   I D C _ S T A T I C 3                                           1 0 7 4 
 
 # d e f i n e   I D C _ S T A T I C 4                                           1 0 7 5 
 
 # d e f i n e   I D C _ D W M                                                   1 0 7 6 
 
 # d e f i n e   I D C _ W O R D M A T C H                                       1 0 7 7 	 / / + [ J O J O ] 
 
 # d e f i n e   I D _ R E M O V E B O O K M A R K                               3 2 7 7 1 
 
 # d e f i n e   I D _ D U M M Y _ R E N A M E P R E S E T                       3 2 7 7 4 
 
 # d e f i n e   I D _ R E N A M E B O O K M A R K                               3 2 7 7 5 
 
 # d e f i n e   I D C _ S T A T I C                                             - 1 
 
 
 
 / /   N e x t   d e f a u l t   v a l u e s   f o r   n e w   o b j e c t s 
 
 / /   
 
 # i f d e f   A P S T U D I O _ I N V O K E D 
 
 # i f n d e f   A P S T U D I O _ R E A D O N L Y _ S Y M B O L S 
 
 # d e f i n e   _ A P S _ N O _ M F C                                           1 
 
 # d e f i n e   _ A P S _ N E X T _ R E S O U R C E _ V A L U E                 1 3 9 
 
 # d e f i n e   _ A P S _ N E X T _ C O M M A N D _ V A L U E                   3 2 7 7 6 
 
 # d e f i n e   _ A P S _ N E X T _ C O N T R O L _ V A L U E                   1 0 7 7 
 
 # d e f i n e   _ A P S _ N E X T _ S Y M E D _ V A L U E                       1 1 0 
 
 # e n d i f 
 
 # e n d i f 
 
 

==> grepWin-1.6.16.695-170401-0000.zip: src/resource.h <==
/ / { { N O _ D E P E N D E N C I E S } } 
 
 / /   M i c r o s o f t   V i s u a l   C + +   g e n e r a t e d   i n c l u d e   f i l e . 
 
 / /   U s e d   b y   D : \ D e v e l o p m e n t \ g r e p w i n \ s r c \ R e s o u r c e s \ g r e p W i n . r c 
 
 / / 
 
 # d e f i n e   I D S _ A P P _ T I T L E                                       1 0 3 
 
 # d e f i n e   I D S _ N A M E                                                 1 0 4 
 
 # d e f i n e   I D S _ S E A R C H S T R I N G                                 1 0 5 
 
 # d e f i n e   I D S _ R E P L A C E S T R I N G                               1 0 6 
 
 # d e f i n e   I D I _ G R E P W I N                                           1 0 7 
 
 # d e f i n e   I D S _ N O T E S T T E X T A V A I L A B L E                   1 0 7 
 
 # d e f i n e   I D S _ S E A R C H S T R I N G E M P T Y                       1 0 8 
 
 # d e f i n e   I D C _ G R E P W I N                                           1 0 9 
 
 # d e f i n e   I D S _ N O R E P L A C E T E X T                               1 1 0 
 
 # d e f i n e   I D S _ N O M A T C H                                           1 1 1 
 
 # d e f i n e   I D S _ P A T T E R N _ T T                                     1 1 2 
 
 # d e f i n e   I D S _ E X C L U D E D I R _ T T                               1 1 3 
 
 # d e f i n e   I D S _ S E A R C H P A T H _ T T                               1 1 4 
 
 # d e f i n e   I D S _ D O T M A T C H N E W L I N E _ T T                     1 1 5 
 
 # d e f i n e   I D S _ S E A R C H T E X T _ T T                               1 1 6 
 
 # d e f i n e   I D S _ O N L Y O N E _ T T                                     1 1 7 
 
 # d e f i n e   I D S _ E D I T M U L T I L I N E _ T T                         1 1 8 
 
 # d e f i n e   I D S _ A B O U T                                               1 1 9 
 
 # d e f i n e   I D S _ L E S S T H A N                                         1 2 0 
 
 # d e f i n e   I D S _ E Q U A L T O                                           1 2 1 
 
 # d e f i n e   I D S _ G R E A T E R T H A N                                   1 2 2 
 
 # d e f i n e   I D S _ S E A R C H                                             1 2 3 
 
 # d e f i n e   I D S _ R E P L A C E C O N F I R M                             1 2 4 
 
 # d e f i n e   I D S _ A N E M P T Y S T R I N G                               1 2 5 
 
 # d e f i n e   I D S _ S T O P                                                 1 2 6 
 
 # d e f i n e   I D S _ S E L E C T P A T H T O S E A R C H                     1 2 7 
 
 # d e f i n e   I D S _ I N F O L A B E L                                       1 2 8 
 
 # d e f i n e   I D D _ S E A R C H D L G                                       1 2 9 
 
 # d e f i n e   I D S _ R E A D E R R O R                                       1 2 9 
 
 # d e f i n e   I D D _ R E G E X T E S T                                       1 3 0 
 
 # d e f i n e   I D S _ B I N A R Y                                             1 3 0 
 
 # d e f i n e   I D D _ N A M E                                                 1 3 1 
 
 # d e f i n e   I D S _ R E G E X O K                                           1 3 1 
 
 # d e f i n e   I D D _ B O O K M A R K S                                       1 3 2 
 
 # d e f i n e   I D S _ R E G E X I N V A L I D                                 1 3 2 
 
 # d e f i n e   I D C _ B K P O P U P                                           1 3 3 
 
 # d e f i n e   I D S _ S I Z E                                                 1 3 3 
 
 # d e f i n e   I D R _ I N F O D L G                                           1 3 4 
 
 # d e f i n e   I D S _ L I N E                                                 1 3 4 
 
 # d e f i n e   I D D _ A B O U T                                               1 3 5 
 
 # d e f i n e   I D S _ M A T C H E S                                           1 3 5 
 
 # d e f i n e   I D R _ S E A R C H D L G                                       1 3 6 
 
 # d e f i n e   I D S _ T E X T                                                 1 3 6 
 
 # d e f i n e   I D D _ M U L T I L I N E E D I T                               1 3 7 
 
 # d e f i n e   I D S _ P A T H                                                 1 3 7 
 
 # d e f i n e   I D D _ S E T T I N G S                                         1 3 8 
 
 # d e f i n e   I D S _ E N C O D I N G                                         1 3 8 
 
 # d e f i n e   I D S _ D A T E M O D I F I E D                                 1 3 9 
 
 # d e f i n e   I D S _ S E L E C T E D I T O R                                 1 4 0 
 
 # d e f i n e   I D S _ O P E N W I T H E D I T O R                             1 4 1 
 
 # d e f i n e   I D S _ O P E N C O N T A I N I N G F O L D E R                 1 4 2 
 
 # d e f i n e   I D S _ C O P Y P A T H                                         1 4 3 
 
 # d e f i n e   I D S _ C O P Y P A T H S                                       1 4 4 
 
 # d e f i n e   I D S _ C O P Y F I L E N A M E                                 1 4 5 
 
 # d e f i n e   I D S _ C O P Y F I L E N A M E S                               1 4 6 
 
 # d e f i n e   I D S _ C O P Y R E S U L T                                     1 4 7 
 
 # d e f i n e   I D S _ C O P Y R E S U L T S                                   1 4 8 
 
 # d e f i n e   I D S _ X M O R E M A T C H E S                                 1 4 9 
 
 # d e f i n e   I D S _ C O N T E X T L I N E                                   1 5 0 
 
 # d e f i n e   I D S _ I N F O L A B E L F I L E                               1 5 1 
 
 # d e f i n e   I D S _ E R R _ R E L A T I V E P A T H                         1 5 2 
 
 # d e f i n e   I D S _ E R R _ I N V A L I D _ P A T H                         1 5 3 
 
 # d e f i n e   I D S _ P R O G R A M S                                         1 5 4 
 
 # d e f i n e   I D S _ A L L F I L E S                                         1 5 5 
 
 # d e f i n e   I D C _ S E A R C H T E X T                                     1 0 0 0 
 
 # d e f i n e   I D C _ R E G E X R A D I O                                     1 0 0 1 
 
 # d e f i n e   I D C _ T E X T R A D I O                                       1 0 0 2 
 
 # d e f i n e   I D C _ R E G E X O K L A B E L                                 1 0 0 4 
 
 # d e f i n e   I D C _ A L L S I Z E R A D I O                                 1 0 0 5 
 
 # d e f i n e   I D C _ S I Z E R A D I O                                       1 0 0 6 
 
 # d e f i n e   I D C _ S I Z E C O M B O                                       1 0 0 7 
 
 # d e f i n e   I D C _ S I Z E E D I T                                         1 0 0 8 
 
 # d e f i n e   I D C _ I N C L U D E S Y S T E M                               1 0 0 9 
 
 # d e f i n e   I D C _ I N C L U D E H I D D E N                               1 0 1 0 
 
 # d e f i n e   I D C _ I N C L U D E S U B F O L D E R S                       1 0 1 1 
 
 # d e f i n e   I D C _ S E A R C H P A T H                                     1 0 1 2 
 
 # d e f i n e   I D C _ S E A R C H P A T H B R O W S E                         1 0 1 3 
 
 # d e f i n e   I D C _ R E S U L T L I S T                                     1 0 1 4 
 
 # d e f i n e   I D C _ G R O U P S E A R C H I N                               1 0 1 5 
 
 # d e f i n e   I D C _ G R O U P S E A R C H F O R                             1 0 1 6 
 
 # d e f i n e   I D C _ G R O U P L I M I T S E A R C H                         1 0 1 7 
 
 # d e f i n e   I D C _ G R O U P S E A R C H R E S U L T S                     1 0 1 8 
 
 # d e f i n e   I D C _ K B T E X T                                             1 0 1 9 
 
 # d e f i n e   I D C _ S E A R C H I N F O L A B E L                           1 0 2 0 
 
 # d e f i n e   I D C _ A D D T O B O O K M A R K S                             1 0 2 1 
 
 # d e f i n e   I D C _ B O O K M A R K S                                       1 0 2 2 
 
 # d e f i n e   I D C _ R E P L A C E T E X T                                   1 0 2 3 
 
 # d e f i n e   I D C _ S E A R C H F O R L A B E L                             1 0 2 6 
 
 # d e f i n e   I D C _ R E P L A C E W I T H L A B E L                         1 0 2 7 
 
 # d e f i n e   I D C _ T E S T R E G E X                                       1 0 2 8 
 
 # d e f i n e   I D C _ C R E A T E B A C K U P                                 1 0 2 9 
 
 # d e f i n e   I D C _ T E X T C O N T E N T                                   1 0 3 0 
 
 # d e f i n e   I D C _ R E G E X M A T C H                                     1 0 3 1 
 
 # d e f i n e   I D C _ R E G E X R E P L A C E D                               1 0 3 2 
 
 # d e f i n e   I D C _ N A M E                                                 1 0 3 7 
 
 # d e f i n e   I D C _ P A T T E R N L A B E L                                 1 0 3 9 
 
 # d e f i n e   I D C _ P A T T E R N                                           1 0 4 0 
 
 # d e f i n e   I D C _ E X C L U D E _ D I R S _ P A T T E R N L A B E L       1 0 4 1 
 
 # d e f i n e   I D C _ C A S E _ S E N S I T I V E                             1 0 4 2 
 
 # d e f i n e   I D C _ V E R S I O N I N F O                                   1 0 4 3 
 
 # d e f i n e   I D C _ E X C L U D E D I R S P A T T E R N                     1 0 4 3 
 
 # d e f i n e   I D C _ D A T E                                                 1 0 4 4 
 
 # d e f i n e   I D C _ W E B L I N K                                           1 0 4 5 
 
 # d e f i n e   I D C _ F I L E P A T T E R N R E G E X                         1 0 4 6 
 
 # d e f i n e   I D C _ F I L E P A T T E R N T E X T                           1 0 4 8 
 
 # d e f i n e   I D C _ R E P L A C E                                           1 0 4 9 
 
 # d e f i n e   I D C _ I N C L U D E B I N A R Y                               1 0 5 0 
 
 # d e f i n e   I D C _ D O T M A T C H N E W L I N E                           1 0 5 1 
 
 # d e f i n e   I D C _ A B O U T L I N K                                       1 0 5 2 
 
 # d e f i n e   I D C _ U T F 8                                                 1 0 5 3 
 
 # d e f i n e   I D C _ I N F O L A B E L                                       1 0 5 6 
 
 # d e f i n e   I D C _ R E S U L T F I L E S                                   1 0 5 9 
 
 # d e f i n e   I D C _ R A D I O 2                                             1 0 6 0 
 
 # d e f i n e   I D C _ R E S U L T C O N T E N T                               1 0 6 0 
 
 # d e f i n e   I D C _ B U T T O N 1                                           1 0 6 1 
 
 # d e f i n e   I D C _ H E L P B U T T O N                                     1 0 6 1 
 
 # d e f i n e   I D C _ E D I T M U L T I L I N E 1                             1 0 6 1 
 
 # d e f i n e   I D C _ C H E C K 1                                             1 0 6 2 
 
 # d e f i n e   I D C _ O N L Y O N E                                           1 0 6 2 
 
 # d e f i n e   I D C _ E S C K E Y                                             1 0 6 2 
 
 # d e f i n e   I D C _ E D I T M U L T I L I N E 2                             1 0 6 3 
 
 # d e f i n e   I D C _ P A T H M R U                                           1 0 6 4 
 
 # d e f i n e   I D C _ H E L P L A B E L                                       1 0 6 5 
 
 # d e f i n e   I D C _ E X C L U D E D I R M R U                               1 0 6 6 
 
 # d e f i n e   I D C _ E D I T O R C M D                                       1 0 6 6 
 
 # d e f i n e   I D C _ P A T T E R N M R U                                     1 0 6 7 
 
 # d e f i n e   I D C _ E D I T O R G R O U P                                   1 0 6 7 
 
 # d e f i n e   I D C _ S T A T I C 1                                           1 0 6 8 
 
 # d e f i n e   I D C _ S T A T I C 2                                           1 0 6 9 
 
 # d e f i n e   I D C _ S E T T I N G S B U T T O N                             1 0 7 1 
 
 # d e f i n e   I D C _ P R O G R E S S                                         1 0 7 2 
 
 # d e f i n e   I D C _ L A N G U A G E                                         1 0 7 3 
 
 # d e f i n e   I D C _ S T A T I C 3                                           1 0 7 4 
 
 # d e f i n e   I D C _ S T A T I C 4                                           1 0 7 5 
 
 # d e f i n e   I D C _ D W M                                                   1 0 7 6 
 
 # d e f i n e   I D C _ W O R D M A T C H                                       1 0 7 7 	 / / + [ J O J O ] 
 
 # d e f i n e   I D C _ E N A B L E _ R E P L A C E                             1 0 7 8 	 / / + [ J O J O ]   5 8 D 8 C C F F 
 
 # d e f i n e   I D M _ G E T I N S T A N C E                                   1 0 7 9 	 / / + [ J O J O ]   5 8 D 8 C C F F 
 
 # d e f i n e   I D _ R E M O V E B O O K M A R K                               3 2 7 7 1 
 
 # d e f i n e   I D _ D U M M Y _ R E N A M E P R E S E T                       3 2 7 7 4 
 
 # d e f i n e   I D _ R E N A M E B O O K M A R K                               3 2 7 7 5 
 
 # d e f i n e   I D C _ S T A T I C                                             - 1 
 
 
 
 / /   N e x t   d e f a u l t   v a l u e s   f o r   n e w   o b j e c t s 
 
 / /   
 
 # i f d e f   A P S T U D I O _ I N V O K E D 
 
 # i f n d e f   A P S T U D I O _ R E A D O N L Y _ S Y M B O L S 
 
 # d e f i n e   _ A P S _ N O _ M F C                                           1 
 
 # d e f i n e   _ A P S _ N E X T _ R E S O U R C E _ V A L U E                 1 3 9 
 
 # d e f i n e   _ A P S _ N E X T _ C O M M A N D _ V A L U E                   3 2 7 7 6 
 
 # d e f i n e   _ A P S _ N E X T _ C O N T R O L _ V A L U E                   1 0 7 7 
 
 # d e f i n e   _ A P S _ N E X T _ S Y M E D _ V A L U E                       1 1 0 
 
 # e n d i f 
 
 # e n d i f 
 
 
